"use strict";
Object.defineProperties(exports, { __esModule: { value: true }, [Symbol.toStringTag]: { value: "Module" } });
const xmldom = require("xmldom");
const utils = require("../utils");
const xpath = require("xpath");
const https = require("https");
const axios = require("axios");
const dom = xmldom.DOMParser;
async function request(url, config) {
  try {
    const { data } = await axios.get(url, {
      responseType: "text",
      ...config,
      httpsAgent: new https.Agent({
        rejectUnauthorized: false
      })
    });
    return data;
  } catch (error) {
    return await request(url, config);
  }
}
async function requestTypes(url) {
  const data = await request(url, { params: { ac: "list" } });
  if (utils.isJSON(data)) {
    return data.class;
  }
  const doc = new dom().parseFromString(data);
  const nodes = xpath.select("//class/ty", doc);
  return Array.from(nodes).map((item) => {
    var _a;
    const id = xpath.select1("@id", item).value;
    const name = (_a = item == null ? void 0 : item.firstChild) == null ? void 0 : _a.data;
    return {
      id: Number(id),
      name
    };
  });
}
async function requestCount(url, params) {
  const data = await request(url, { params: { ac: "list", ...params } });
  if (utils.isJSON(data)) {
    return {
      pageCount: data.pagecount,
      recordCount: data.total
    };
  }
  const doc = new dom().parseFromString(data);
  const pageCount = xpath.select1("//list/@pagecount", doc).value;
  const recordCount = xpath.select1("//list/@recordcount", doc).value;
  return {
    pageCount: Number(pageCount),
    recordCount: Number(recordCount)
  };
}
async function requestPage(url, pg, params) {
  const data = await request(url, {
    params: { ac: "videolist", pg, ...params }
  });
  if (utils.isJSON(data)) {
    return data.list;
  }
  const doc = new dom().parseFromString(data);
  const nodes = xpath.select("//list/video", doc);
  if (!nodes || (nodes == null ? void 0 : nodes.length) === 0) {
    return null;
  }
  return Array.from(nodes).map((item) => {
    const last = selectParam(xpath, item, "//last");
    const id = selectParam(xpath, item, "//id");
    const urls = Array.from(xpath.select("//dl/dd", item)).map((node) => {
      var _a;
      return {
        flag: xpath.select1("@flag", node).value,
        text: (_a = node == null ? void 0 : node.firstChild) == null ? void 0 : _a.data
      };
    });
    return {
      last,
      id: Number(id),
      tid: Number(selectParam(xpath, item, "//tid")),
      name: selectParam(xpath, item, "//name"),
      type: selectParam(xpath, item, "//type"),
      pic: selectParam(xpath, item, "//pic"),
      lang: selectParam(xpath, item, "//lang"),
      area: selectParam(xpath, item, "//area"),
      year: Number(selectParam(xpath, item, "//year")),
      state: selectParam(xpath, item, "//state"),
      note: selectParam(xpath, item, "//note"),
      actor: selectParam(xpath, item, "//actor"),
      director: selectParam(xpath, item, "//director"),
      des: selectParam(xpath, item, "//des"),
      urls: JSON.stringify(urls)
    };
  });
}
function selectParam(xpath2, item, selector) {
  var _a, _b;
  return ((_b = (_a = xpath2.select1(selector, item)) == null ? void 0 : _a.firstChild) == null ? void 0 : _b.data) || "";
}
exports.default = request;
exports.requestCount = requestCount;
exports.requestPage = requestPage;
exports.requestTypes = requestTypes;
